#
# spec file for package python-jsonpatch
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} > 1500
%bcond_without libalternatives
%else
%bcond_with libalternatives
%endif

%{?sle15_python_module_pythons}
Name:           python-jsonpatch
Version:        1.33
Release:        1.5
Summary:        Python - JSON-Patches
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/stefankoegl/python-json-patch
Source:         https://files.pythonhosted.org/packages/source/j/jsonpatch/jsonpatch-%{version}.tar.gz
BuildRequires:  %{python_module jsonpointer >= 1.9}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros >= 20210929
%if %{with libalternatives}
Requires:       alts
BuildRequires:  alts
%else
Requires(post): update-alternatives
Requires(preun):update-alternatives
%endif
Requires:       python-jsonpointer >= 1.9
BuildArch:      noarch
%python_subpackages

%description
Python module to apply JSON-Patches (according to RFC 6902).

%prep
%setup -q -n jsonpatch-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

# Prepare for update-alternatives usage
%python_clone -a %{buildroot}%{_bindir}/jsonpatch
rm %{buildroot}%{_bindir}/jsondiff

%check
%pyunittest -v tests

%pre
# If libalternatives is used: Removing old update-alternatives entries.
%python_libalternatives_reset_alternative jsonpatch

%post
%python_install_alternative jsonpatch

%postun
%python_uninstall_alternative jsonpatch

%files %{python_files}
%license LICENSE
%doc AUTHORS README.md
%python_alternative %{_bindir}/jsonpatch
%{python_sitelib}/jsonpatch*
%pycache_only %{python_sitelib}/__pycache__/jsonpatch*.pyc

%changelog
* Mon Nov 27 2023 Dirk Müller <dmueller@suse.com>
- update 1.33:
  * fix invalid remove index
  * remove unused import
  * feat(jsondiff): Add support for preserving Unicode characters
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Tue Oct 12 2021 Ben Greiner <code@bnavigator.de>
- Fix requirements
* Tue Oct  5 2021 schubi <schubi@localhost>
- Added BuildRequires:  alts
* Thu Sep 30 2021 Stefan Schubert <schubi@suse.de>
- Use libalternatives instead of update-alternatives.
* Fri Sep 17 2021 Matej Cepl <mcepl@suse.com>
- Don't use python setup.py test expression.
* Tue May 18 2021 Dirk Müller <dmueller@suse.com>
- update to 1.32:
  * take_index causing 'move' of incorrect values due to bad True==1 comparison
* Thu Apr 22 2021 Dirk Müller <dmueller@suse.com>
- update to 1.31:
  * Add support for preserving Unicode charaters
  * remove pypy build
* Sun Dec 20 2020 Dirk Müller <dmueller@suse.com>
- update to 1.28:
  * Make it possible for from_diff to support custom types (issue #107)
  * Python 3.9 support
* Tue Aug  4 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.26:
  * bugfixes (reject invalid json patches)
* Fri Feb 28 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.25:
  * bugfixes, 3.8 support
* Wed Sep 11 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.24:
  * test with python 3.8
* Fri May 17 2019 Scott Wulf <swulf@suse.com>
- Removing conflict with jsondiff
  * Reasoning:
  - moto requires cfn-lint and jsondiff
  - cfn-lint requires jsonpatch
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Mon May 14 2018 tchvatal@suse.com
- Version update to 1.23:
  * dropped support for python 2.6
  * More testcases for various bugs
  * Various code cleanups
- Run tests
- Conflict with python-jsondiff as it provides jsondiff binary too
* Tue Aug  8 2017 tbechtold@suse.com
- Fix Requires
* Fri Jul 28 2017 darin@darins.net
- Convert packaging to Singlespec
- update to 1.16
* Tue Nov 15 2016 dmueller@suse.com
- udpate to 1.14.0
* Mon Aug 15 2016 toddrme2178@gmail.com
- Fix update-alternatives implementation.
* Mon Jun 22 2015 tbechtold@suse.com
- update to 1.11.0:
  * bump version to 1.11
  * Fix tests for Python 3.2
  * bump version to 1.10
  * Require pypandoc instead of pandoc for setup.py
  * Fix make_patch with unicode paths
  * Enable container-based builds on Travis-CI
- Update Requires according to requirements.txt
* Wed Feb  4 2015 tbechtold@suse.com
- update to version 1.9:
  * bump version to 1.9
  * require jsonpointer>=1.5
  * Use ABCs instead of list/dict, fixes #33
  * Convert readme from markdown to rst for PyPI
  * Added Python 3.4 and PyPy3 to the build matrix.
  * bump version to 1.8
  * Fix installation of commandline scripts (fixes #31)
  * raise JsonPatchException on missing patch attributes
  * Add wheel as dev dependency for wheel packages
- Requires(pre) coreutils to be able to use "rm" cmd
* Sat Nov  8 2014 Led <ledest@gmail.com>
- fix bashisms in pre script
* Mon Sep 15 2014 tbechtold@suse.com
- update to version 1.7:
  * bump version to 1.7
  * [Setup] use utf-8 explicitly in setup.py
  * bump version to 1.6
  * Fix make_patch() when root is an array (fixes #28)
  * Merge branch 'remove-error' of https://github.com/umago/python-json-patch
  * Improve error message when removing non-existent objects
  * bump version to 1.5
  * fix test for Python 3
  * fix make_patch where obj keys contain "/", fixes #26
- Update Requires for python-jsonpointer
* Fri Nov 15 2013 speilicke@suse.com
- Don't ghost /etc/alternatives/..., post-build-checks on 12.2 fail
* Thu Nov 14 2013 speilicke@suse.com
- Fix update-alternatives (SLE_11_SP3)
* Mon Oct 21 2013 dmueller@suse.com
- update to 1.3:
  * Improved Tests, add command line utilities
- add update-alternatives
* Thu Jul 11 2013 dmueller@suse.com
- update to 1.1:
  * various python 3.x fixes
* Mon Apr 29 2013 dmueller@suse.com
- update to 1.0
  * first stable release, some bugfixes
* Fri Feb 22 2013 saschpe@suse.de
- Initial version
